@@ -115,6 +115,7 @@ def reread_filetype_plugins():
     global _on_postimport
     global _on_preprocess
     global _on_postprocess
+    global _on_postadd
     _on_import           = defaultdict(list)
     _on_postimport       = defaultdict(list)
     _on_preprocess       = defaultdict(list)
@@ -445,14 +446,14 @@ def plugin_for_input_format(fmt):
             return plugin
 
 def all_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         for format in plugin.file_types:
             formats.add(format)
     return formats
 
 def available_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         if not is_disabled(plugin):
             for format in plugin.file_types:
