@@ -13,6 +13,7 @@ from urlparse import urlparse
 
 from lxml import etree
 
+from calibre.ebooks import escape_xpath_attr
 from calibre.ebooks.chardet import xml_to_unicode
 from calibre.constants import __appname__, __version__, filesystem_encoding
 from calibre.ebooks.metadata.toc import TOC
@@ -1120,7 +1121,7 @@ class OPF(object):  # {{{
                 uuid_elem = self.root.attrib[attr]
                 break
         if uuid_elem:
-            matches = self.root.xpath('//*[@id=%r]'%uuid_elem)
+            matches = self.root.xpath('//*[@id=%s]'%escape_xpath_attr(uuid_elem))
             if matches:
                 for m in matches:
                     raw = m.text
@@ -1276,9 +1277,9 @@ class OPF(object):  # {{{
                      'isbn', 'tags', 'category', 'comments', 'book_producer',
                      'pubdate', 'user_categories', 'author_link_map'):
             val = getattr(mi, attr, None)
-            is_null = val is None or val in ((), [], (None, None), {})
+            is_null = val is None or val in ((), [], (None, None), {}) or (attr == 'rating' and val < 0.1)
             if is_null:
-                if apply_null and attr in {'series', 'tags', 'isbn', 'comments', 'publisher'}:
+                if apply_null and attr in {'series', 'tags', 'isbn', 'comments', 'publisher', 'rating'}:
                     setattr(self, attr, ([] if attr == 'tags' else None))
             else:
                 setattr(self, attr, val)
